/* read and write "IMG" format files.

   IMG files are simply streams of data bytes, suitable for use with
   SIMH.

*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <assert.h>

#include "helios.h"
#include "imgdisk.h"

// ========================================================================
// dump .img disk image
// return 0 on success, !=0 on failure
// ========================================================================

int
dump_img_file(const char *filename, svh_disk_t *disk)
{
    FILE *fp;
    int t, s, i;

    assert(disk != NULL);

    fp = fopen(filename, "wb");
    if (!fp) {
	fprintf(stderr, "Error opening file '%s' for writing\n", filename);
	return 1;
    }

    for(t=0; t<TRACKS; t++) {
	for(s=0; s<SECTORS; s++) {

	    int hdr_err    = disk->trk[t].sector[s].hdr_error;
	    int hdr_bytes  = disk->trk[t].sector[s].hdr_bytes;
	    int data_err   = disk->trk[t].sector[s].data_error;
	    int data_bytes = disk->trk[t].sector[s].data_bytes;

	    if(hdr_err || data_err) {
		fprintf(stderr,"Warning:  Track %d Sector %d: Header or "
			"data error.\n",t,s);
	    }

	    // dump data block
	    if (data_bytes != 0) {
		i = fwrite(disk->trk[t].sector[s].data,1,data_bytes,fp);
		if(i != data_bytes) {
			fprintf(stderr,"Warning: Wrote %d, expected %d bytes "
			   "for track %d, sector %d\n",i,data_bytes,t,s);
		}
	    }

	} // for(s)
    } // for(t)

    fclose(fp);
    return 0;	// success
}
